@@ -262,8 +262,6 @@ class AppInstall(SimpleGladeApp):
         # ... and open the cache
         self.updateCache(filter_to_restore)
 
-        self.search_entry.grab_focus()
-
         self.textview_description.hook(self.cache, 
                                        self.menu, 
                                        self.icons,
@@ -279,7 +277,6 @@ class AppInstall(SimpleGladeApp):
         # if a pkgname is in the set, a dialog was already displayed to the
         # user about this (ugly ...)
         self.multiple_pkgs_seen = set()
-
         self.window_main.show()
 
         # create a worker that does the actual installing etc
@@ -295,6 +292,12 @@ class AppInstall(SimpleGladeApp):
         # now check if the cache is up-to-date
         if not options.test_mode:
             self._checkAptCache()
+            
+        # make sure the focus is rigth
+        if gtk.REALIZED & self.search_entry.flags():
+            self.search_entry.grab_focus()
+        else:
+            self.treeview_packages.grab_focus()
 
     def addCD(self):
         """ check for addon cd and if available and not yet added
@@ -700,6 +703,8 @@ class AppInstall(SimpleGladeApp):
         Ask the user if a specified componet of the distribution 
         should be enabled
         """
+        primary=""
+        secondary=""
         dia = gtk.MessageDialog(parent=self.window_main,
                                 type=gtk.MESSAGE_QUESTION,
                                 buttons=gtk.BUTTONS_CANCEL)
