@@ -1,10 +1,16 @@
+
 import Default
 
 from AppInstall.Menu import SHOW_ALL, SHOW_ONLY_SUPPORTED, SHOW_ONLY_FREE, SHOW_ONLY_MAIN, SHOW_ONLY_PROPRIETARY, SHOW_ONLY_THIRD_PARTY, SHOW_ONLY_INSTALLED
+from AppInstall.Util import *
+
+import datetime
+import locale
 
 from gettext import gettext as _
 
 class Distribution(Default.Distribution):
+
     def __init__(self):
         Default.Distribution.__init__(self)
         # Dictonary of all available filters with corresponding choser name
@@ -12,26 +18,12 @@ class Distribution(Default.Distribution):
         # The installed filter will be automatically added in non-installer mode
         # The primary and secondary filters are separated
         self.filters_primary = {
-            SHOW_ALL : (_("All available applications"),
-                        _("Show all applications including ones "
-                          "which are possibly restricted by law or "
-                          "copyright, unsupported by Canonical Ltd. or "
-                          "not part of Ubuntu")),
-            SHOW_ONLY_FREE : (_("All Open Source applications"),
-                              _("Show all Ubuntu applications which can be "
-                                "freely used, modified and distributed. This "
-                                "includes a large variety of community "
-                                "maintained applications"))
+            SHOW_ALL : (_("All available applications"), ""),
+            SHOW_ONLY_FREE : (_("All Open Source applications"), ""),
             }
         self.filters_secondary = {
-            SHOW_ONLY_SUPPORTED : (_("Supported applications"),
-                                   _("Show only applications which come with "
-                                     "full technical and security support by "
-                                     "Canonical Ltd.")),
-            SHOW_ONLY_THIRD_PARTY :(_("Third party applications"),
-                                    _("Show only applications that are "
-                                      "provided by independent software vendors"
-                                      " and are not part of Ubuntu"))
+            SHOW_ONLY_SUPPORTED : (_("Canonical-maintained applications"), ""),
+            SHOW_ONLY_THIRD_PARTY :(_("Third party applications"), ""),
             }
         # List of components whose applications should not be installed
         # before asking for a confirmation
@@ -67,7 +59,7 @@ class Distribution(Default.Distribution):
 
         self.dependencies_map = [
             # KDE
-            (("kdelibs4c2a","python-kde3","libqt3-mt"),
+            (("kdelibs5","python-kde4","libqtgui4"),
             # %s is the name of an application
              None,
              "application-kde"),
@@ -132,3 +124,76 @@ class Distribution(Default.Distribution):
                         emblems.append((icon_name, tooltip))
                         break
         return emblems
+
+    def get_codec_information_link(self):
+        url = "https://codecs.canonical.com"
+        label = _("Buy Licensed Plug-ins...")
+        return (label, url)
+
+    def get_maintenance_status(self, app, cache):
+
+        # try to figure out the support dates of the release and make
+        # sure to look only for stuff in "Ubuntu" and "distro_codename"
+        # (to exclude stuff in ubuntu-updates for the support time 
+        # calculation because the "Release" file time for that gets
+        # updated regularly)
+        releasef = get_release_filename_for_pkg(cache, app.pkgname, 
+                                                "Ubuntu", self.get_codename())
+        time_t = get_release_date_from_release_file(releasef)
+        # check the release date and show support information
+        # based on this
+        if time_t:
+            release_date = datetime.datetime.fromtimestamp(time_t)
+            #print "release_date: ", release_date
+            now = datetime.datetime.now()
+            release_age = (now - release_date).days
+            #print "release age: ", release_age
+
+            # mvo: we do not define the end date very precisely
+            #      currently this is why it will just display a end
+            #      range
+            (support_end_year, support_end_month) = get_maintenance_end_date(release_date, 18)
+            support_end_month_str = locale.nl_langinfo(getattr(locale,"MON_%d" % support_end_month))
+             # check if the support has ended
+            support_ended = (now.year >= support_end_year and 
+                             now.month > support_end_month)
+            if app.component == "main":
+                if support_ended:
+                    return _("Canonical does no longer provide "
+                             "updates for %s in Ubuntu %s. "
+                             "Updates may be available in a newer version of "
+                             "Ubuntu.") % (app.name, self.get_distro_release())
+                else:
+                    return _("Canonical provides critical updates for %s until "
+                             "%s %s.") % (app.name, 
+                                          support_end_month_str, 
+                                          support_end_year)
+            elif app.component == "restricted":
+                if support_ended:
+                    return _("Canonical does no longer provide "
+                             "updates for %s in Ubuntu %s. "
+                             "Updates may be available in a newer version of "
+                             "Ubuntu.") % (app.name, self.get_distro_release())
+                else:
+                    return _("Canonical provides critical updates supplied by the "
+                             "developers of %s until %s %s.") % (app.name, 
+                                                                 support_end_month_str, 
+                                                                 support_end_year)
+                
+        # if we couldn't fiure a support date, use a generic maintenance
+        # string without the date
+        if app.thirdparty or app.channel:
+            return _("Canonical does not provide updates for %s. "
+                     "Some updates may be provided by the third party "
+                     "vendor.") % app.name
+        elif app.component == "main":
+            return _("Canonical provides critical updates for %s.") % app.name
+        elif app.component == "restricted":
+            return _("Canonical provides critical updates supplied by the "
+                     "developers of %s.") % app.name
+        elif app.component == "universe" or app.component == "multiverse":
+            return _("Canonical does not provide updates for %s. "
+                     "Some updates may be provided by the "
+                     "Ubuntu community.") % app.name
+        return _("Application %s has a unkown maintenance status.")
+        
