@@ -63,6 +63,7 @@ def generate_mime_map(desktop_dir, cache_dir):
 	    g[key] = ' '.join(l)
 	g.sync()
 	g.close()
+	os.chmod(os.path.join(cache_dir, "gai-"+dictname+"-map.gdbm"), 0644)
 
 def generate_menu_cache(desktop_dir, cache_dir):
     # the regular menu cache
@@ -82,7 +83,9 @@ def generate_menu_cache(desktop_dir, cache_dir):
                     mime_pickle[cat] = []
                 mime_pickle[cat].append(item)
     pickle.dump(mime_pickle, open('%s/mime_menu.p' % cache_dir,'w'), 2)
+    os.chmod('%s/mime_menu.p' % cache_dir, 0644)
     pickle.dump(codec_pickle, open('%s/codec_menu.p' % cache_dir,'w'), 2)
+    os.chmod('%s/codec_menu.p' % cache_dir, 0644)
 
 def main():
  	parser = OptionParser()
