@@ -14,6 +14,13 @@
 # - lots of packages have multiple desktop files for the same application
 #   abiword, abiword-gnome, abiword-gtk
 
+print """
+#
+# DEPRECATED in favor of the archive-crawler
+# https://code.edge.launchpad.net/~mvo/archive-crawler/mvo
+#
+"""
+
 import os
 import tarfile
 import sys
